==> aTunes_1.12.0.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/actions/CustomSearchAction.java <==
/*
 * aTunes 1.12.0
 * Copyright (C) 2006-2009 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.actions;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;

import javax.swing.AbstractAction;
import javax.swing.KeyStroke;

import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.kernel.handlers.SearchHandler;
import net.sourceforge.atunes.utils.LanguageTool;

/**
 * Displays custom search dialog
 * 
 * @author fleax
 * 
 */
public class CustomSearchAction extends AbstractAction {

	/**
	 * 
	 */
	private static final long serialVersionUID = 7036619806075628842L;

	CustomSearchAction() {
		super(LanguageTool.getString("SEARCH"), ImageLoader.SEARCH);
		putValue(SHORT_DESCRIPTION, LanguageTool.getString("SEARCH"));
		putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke(KeyEvent.VK_D, ActionEvent.CTRL_MASK));
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		SearchHandler.getInstance().startSearch();
	}

}

==> aTunes_1.13.0.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/actions/CustomSearchAction.java <==
/*
 * aTunes 1.13.0
 * Copyright (C) 2006-2009 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.actions;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;

import javax.swing.AbstractAction;
import javax.swing.KeyStroke;

import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.kernel.modules.search.SearchHandler;
import net.sourceforge.atunes.utils.LanguageTool;

/**
 * Displays custom search dialog
 * 
 * @author fleax
 * 
 */
public class CustomSearchAction extends AbstractAction {

    private static final long serialVersionUID = 7036619806075628842L;

    CustomSearchAction() {
        super(LanguageTool.getString("SEARCH"), ImageLoader.SEARCH);
        putValue(SHORT_DESCRIPTION, LanguageTool.getString("SEARCH"));
        putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke(KeyEvent.VK_D, ActionEvent.CTRL_MASK));
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        SearchHandler.getInstance().startSearch();
    }

}
